searchData={"items":[{"type":"module","title":"Ueberauth.Strategy.Twitch","doc":"Provides an Ueberauth strategy for authenticating with Twitch.\n\n#","ref":"Ueberauth.Strategy.Twitch.html"},{"type":"module","title":"Setup - Ueberauth.Strategy.Twitch","doc":"Create an application in Twitch for you to use.\n\nRegister a new application at: [your twitch developer page](https://dev.twitch.tv/) and get the `client_id` and `client_secret`.\n\nInclude the provider in your configuration for Ueberauth\n\n    config :ueberauth, Ueberauth,\n      providers: [\n        twitch: { Ueberauth.Strategy.Twitch, [] }\n      ]\n\nThen include the configuration for twitch.\n\n    config :ueberauth, Ueberauth.Strategy.Twitch.OAuth,\n      client_id: System.get_env(\"TWITCH_CLIENT_ID\"),\n      client_secret: System.get_env(\"TWITCH_CLIENT_SECRET\")\n\nIf you haven't already, create a pipeline and setup routes for your callback handler\n\n  pipeline :browser do\n    plug Ueberauth\n    ...\n end\n\n    scope \"/auth\", MyApp do\n      pipe_through :browser\n\n      get \"/:provider\", AuthController, :request\n      get \"/:provider/callback\", AuthController, :callback\n    end\n\n\nCreate an endpoint for the callback where you will handle the `Ueberauth.Auth` struct\n\n    defmodule MyApp.AuthController do\n      use MyApp.Web, :controller\n\n      def callback_phase(%{ assigns: %{ ueberauth_failure: fails } } = conn, _params) do\n        # do things with the failure\n      end\n\n      def callback_phase(%{ assigns: %{ ueberauth_auth: auth } } = conn, params) do\n        # do things with the auth\n      end\n    end\n\nYou can edit the behaviour of the Strategy by including some options when you register your provider.\n\nDefault is `user:read:email`\n\nTo set the default 'scopes' (permissions):\n\n    config :ueberauth, Ueberauth,\n      providers: [\n        twitch: { Ueberauth.Strategy.Twitch, [default_scope: \"user:read:email\"] }\n      ]","ref":"Ueberauth.Strategy.Twitch.html#module-setup"},{"type":"function","title":"Ueberauth.Strategy.Twitch.credentials/1","doc":"Includes the credentials from the Twitch response.","ref":"Ueberauth.Strategy.Twitch.html#credentials/1"},{"type":"function","title":"Ueberauth.Strategy.Twitch.default_options/0","doc":"","ref":"Ueberauth.Strategy.Twitch.html#default_options/0"},{"type":"function","title":"Ueberauth.Strategy.Twitch.extra/1","doc":"Stores the raw information (including the token) obtained from the Twitch callback.","ref":"Ueberauth.Strategy.Twitch.html#extra/1"},{"type":"function","title":"Ueberauth.Strategy.Twitch.fetch_email/1","doc":"","ref":"Ueberauth.Strategy.Twitch.html#fetch_email/1"},{"type":"function","title":"Ueberauth.Strategy.Twitch.handle_cleanup!/1","doc":"Cleans up the private area of the connection used for passing the raw Twitch response around during the callback.","ref":"Ueberauth.Strategy.Twitch.html#handle_cleanup!/1"},{"type":"function","title":"Ueberauth.Strategy.Twitch.handle_request!/1","doc":"Handles the initial redirect to the twitch authentication page.\n\nTo customize the scope (permissions) that are requested by twitch include them as part of your url:\n\n    \"/oauth2/token?scope=api read_user read_registry\"\n\nYou can also include a `state` param that twitch will return to you.","ref":"Ueberauth.Strategy.Twitch.html#handle_request!/1"},{"type":"function","title":"Ueberauth.Strategy.Twitch.info/1","doc":"Fetches the fields to populate the info section of the `Ueberauth.Auth` struct.","ref":"Ueberauth.Strategy.Twitch.html#info/1"},{"type":"function","title":"Ueberauth.Strategy.Twitch.uid/1","doc":"Fetches the uid field from the Twitch response. This defaults to the option `uid_field` which in-turn defaults to `id`","ref":"Ueberauth.Strategy.Twitch.html#uid/1"},{"type":"module","title":"Ueberauth.Strategy.Twitch.OAuth","doc":"An implementation of OAuth2 for twitch.\n\nTo add your `client_id` and `client_secret` include these values in your configuration.\n\n    config :ueberauth, Ueberauth.Strategy.Twitch.OAuth,\n      client_id: System.get_env(\"TWITCH_CLIENT_ID\"),\n      client_secret: System.get_env(\"TWITCH_CLIENT_SECRET\")","ref":"Ueberauth.Strategy.Twitch.OAuth.html"},{"type":"function","title":"Ueberauth.Strategy.Twitch.OAuth.authorize_url/2","doc":"","ref":"Ueberauth.Strategy.Twitch.OAuth.html#authorize_url/2"},{"type":"function","title":"Ueberauth.Strategy.Twitch.OAuth.authorize_url!/2","doc":"Provides the authorize url for the request phase of Ueberauth. No need to call this usually.","ref":"Ueberauth.Strategy.Twitch.OAuth.html#authorize_url!/2"},{"type":"function","title":"Ueberauth.Strategy.Twitch.OAuth.client/1","doc":"Construct a client for requests to Twitch.\n\nOptionally include any OAuth2 options here to be merged with the defaults.\n\n    Ueberauth.Strategy.Twitch.OAuth.client(redirect_uri: \"http://localhost:4000/auth/twitch/callback\")\n\nThis will be setup automatically for you in `Ueberauth.Strategy.Twitch`.\nThese options are only useful for usage outside the normal callback phase of Ueberauth.","ref":"Ueberauth.Strategy.Twitch.OAuth.html#client/1"},{"type":"function","title":"Ueberauth.Strategy.Twitch.OAuth.get/4","doc":"","ref":"Ueberauth.Strategy.Twitch.OAuth.html#get/4"},{"type":"function","title":"Ueberauth.Strategy.Twitch.OAuth.get_token/3","doc":"","ref":"Ueberauth.Strategy.Twitch.OAuth.html#get_token/3"},{"type":"function","title":"Ueberauth.Strategy.Twitch.OAuth.get_token!/2","doc":"","ref":"Ueberauth.Strategy.Twitch.OAuth.html#get_token!/2"},{"type":"extras","title":"Overview","doc":"# Überauth Twitch\n\n[![Hex Version](https://img.shields.io/hexpm/v/ueberauth_twitch.svg)](https://hex.pm/packages/ueberauth_twitch)\n\n> Twitch OAuth2 strategy for Überauth.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"1. Setup your application in Twitch under your profile [applications menu][twitch-apps]\n\n1. Add `:ueberauth_twitch` to your list of dependencies in `mix.exs`:\n\n    ```elixir\n    def deps do\n      [{:ueberauth_twitch, \"~> 0.1.0\"}]\n    end\n    ```\n\n1. Add Twitch to your Überauth configuration to your `config.exs`:\n\n    ```elixir\n    config :ueberauth, Ueberauth,\n      providers: [\n        twitch: {Ueberauth.Strategy.Twitch, [default_scope: \"user:read:email\"]}\n      ]\n    ```\n\n1.  Add your provider configuration to your `config.exs` next, all this information should mirror what you have for your\n    Twitch app:\n\n    ```elixir\n    config :ueberauth, Ueberauth.Strategy.Twitch.OAuth,\n      client_id: System.get_env(\"TWITCH_CLIENT_ID\"),\n      client_secret: System.get_env(\"TWITCH_CLIENT_SECRET\"),\n      redirect_uri: System.get_env(\"TWITCH_REDIRECT_URI\")\n    ```\n\n1.  Include the Üeberauth plug in your `router.exs` in the browser or custom pipeline:\n\n    ```elixir\n    defmodule TwitchWeb.Router do\n       use TwitchWeb, :router\n\n       pipeline :browser do\n         plug Ueberauth\n       ...\n      end\n    end\n    ```\n\n1.  Define the request and callback routes in your `router.exs`:\n\n    ```elixir\n    scope \"/auth\", TwitchWeb do\n      pipe_through :browser\n\n      get \"/:provider\", AuthController, :request\n      get \"/:provider/callback\", AuthController, :callback\n    end\n    ```\n\n1. Create a new controller or use an existing controller that implements callbacks to deal with `Ueberauth.Auth` and `Ueberauth.Failure` responses from Twitch.\n\n    ```elixir\n      defmodule TwitchWeb.AuthController do\n        use TwitchWeb, :controller\n\n        def callback(%{assigns: %{ueberauth_failure: _fails}} = conn, _params) do\n          Logger.debug(_fails)\n          conn\n          |> put_flash(:error, \"Failed to authenticate.\")\n          |> redirect(to: \"/\")\n        end\n\n        def callback(%{assigns: %{ueberauth_auth: auth}} = conn, _params) do\n          # This is an example of how you can pass the auth information to\n          # a function that you implement that will register or login a user\n          case UserFromAuth.find_or_create(auth) do\n            {:ok, user} ->\n              conn\n              |> put_flash(:info, \"Successfully authenticated.\")\n              |> put_session(:current_user, user)\n              |> configure_session(renew: true)\n              |> redirect(to: \"/\")\n\n            {:error, reason} ->\n              conn\n              |> put_flash(:error, reason)\n              |> redirect(to: \"/\")\n          end\n        end\n      end\n    ```","ref":"readme.html#installation"},{"type":"extras","title":"Calling - Overview","doc":"Once your setup, you can initiate auth using the following URL, unless you changed the routes from the guide:\n\n    /auth/twitch","ref":"readme.html#calling"},{"type":"extras","title":"Missing User Email Address - Overview","doc":"Twitch allows a user to sign up without providing an email address (they can use a phone verify their account). As a result instead of providing an empty string when an email address is not present you will follow the following format: `id+login@no-email-provided.twitch.tv`\n\n<!--","ref":"readme.html#missing-user-email-address"},{"type":"extras","title":"Documentation - Overview","doc":"The docs can be found at [ueberauth_twitch][package-docs] on [Hex Docs][hex-docs].\n\n[hex-docs]: https://hexdocs.pm\n[package-docs]: https://hexdocs.pm/ueberauth_twitch -->","ref":"readme.html#documentation"},{"type":"extras","title":"Changelog","doc":"# Change Log","ref":"changelog.html"},{"type":"extras","title":"v0.2.0 - 2024-03-19 - Changelog","doc":"#","ref":"changelog.html#v0-2-0-2024-03-19"},{"type":"extras","title":"Features: - Changelog","doc":"- Authenticated users without an e-mail address get a generated private email instead of being set to null\n\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Chores: - Changelog","doc":"- Upgrade dependencies\n- Upgrade ueberauth from 0.7.0 to 0.10.8\n- Upgrade oauth2 from 2.0.0 to 2.1.0\n- Add GitHub Action to run tests\n- Fix broken tests","ref":"changelog.html#chores"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}